macro_rules! setup {
() => { ... };
}Expand description
Initializes the Integration enums as well as pi and e
Setup macro
This macro aids by automatically bringing into scope the IntegrationMethod and MultipleIntegrationMethod
enum variants, so you can just write the variant when specifying a method on the integral!, line_integral! or
surface_integral! macros. This way, just write Simpson13(100) instead of IntegrationMethod::Simpson13(100).
This macro also automatically imports the constants pi and e from the std library, so it’s recommended to
use it at the begging of the programs for simplicity.
Examples
use vector_calculus::*;
setup!();
assert!(near!(PI, 3.141592))